]> git.sur5r.net Git - groeck-it87/commitdiff
Blacklist IT8792E on AX370-Gaming K7
authorGuenter Roeck <linux@roeck-us.net>
Tue, 18 Apr 2017 21:49:22 +0000 (14:49 -0700)
committerGuenter Roeck <linux@roeck-us.net>
Tue, 18 Apr 2017 21:49:22 +0000 (14:49 -0700)
Accessing it may result in a system hang.

Signed-off-by: Guenter Roeck <linux@roeck-us.net>
it87.c

diff --git a/it87.c b/it87.c
index 21e5724409cacdd3986e7df3249bfa0cf247b7ce..538f6b6d4fb0b2060673bb16d1316b247c980cca 100644 (file)
--- a/it87.c
+++ b/it87.c
@@ -3685,7 +3685,7 @@ struct it87_dmi_data {
 };
 
 /*
* On Gigabyte AB350 boards, accesses to the Super-IO chip
  * at address 0x4e/0x4f can result in a system hang.
  * Accesses to address 0x2e/0x2f need to be mutex protected.
  */
@@ -3721,6 +3721,13 @@ static const struct dmi_system_id it87_dmi_table[] __initconst = {
                },
                .driver_data = &gigabyte_ab350_gaming,
        },
+       {
+               .matches = {
+                       DMI_MATCH(DMI_SYS_VENDOR, "Gigabyte Technology Co., Ltd."),
+                       DMI_MATCH(DMI_BOARD_NAME, "AX370-Gaming K7"),
+               },
+               .driver_data = &gigabyte_ab350_gaming,
+       },
        {
                .matches = {
                        DMI_MATCH(DMI_BOARD_VENDOR, "nVIDIA"),
@@ -3685,7 +3685,7 @@ struct it87_dmi_data {
 
 /*
- * On Gigabyte AB350 boards, accesses to the Super-IO chip
+ * On Gigabyte AB350 and AX370 boards, accesses to the Super-IO chip
  * at address 0x4e/0x4f can result in a system hang.
  * Accesses to address 0x2e/0x2f need to be mutex protected.